# Connection: root@localhost:3306
# Host: localhost
# Saved: 2004-04-25 22:03:47
# 
# Connection: root@localhost:3306
# Host: localhost
# Saved: 2004-04-22 20:47:04

drop table mail_alias;
drop table squid_user_history;
drop table squid_user;
drop table novell_user;
drop table unix_user;
drop table groups_acl;
drop table groups_member;
drop table groups_history;
drop table login;
drop table person;
drop table class_group;
drop table squid_group;
drop table unix_group;
drop table groups;
drop table role;
drop table sequence;

/* 
 * sequence : table de dfinition des squences numriques "hors systme"
 */

create table sequence (
  /* cl */
  id int auto_increment not null,
  /* nom de la squence */
  name varchar(20) not null,
  /* prochaine valeur */
  value int not null,
  /* contraintes */
  primary key(id),
  unique key(name)
) type = innodb;

/*
 * valeurs initiales pour la table squence
 */
insert into sequence (name, value) values ("uid_number", 1000);
insert into sequence (name, value) values ("gid_number", 1000);


/*
 * persons : table des utilisateurs physiques, indpendante du login ou des autres caractristiques
*/

create table person (
   /* cl */
  id int auto_increment not null,
  /* nom */
  name varchar(40) not null,
  /* prnom */
  given_name varchar(30),
  /* nom de la source de cration */
  src varchar(10),
  /* identifiant unique dans la source */
  src_num varchar(20),
  /* la personne est-elle encore considre comme prsente 
   *  quel est son statut
  */
  present varchar(5),
  /* date de cration dans le systme */
  creation_date timestamp,
  /* date de sortie du systme */
  exit_date timestamp,
  /* les contraintes */
  primary key(id),
  unique key(src, src_num)
)  type = innodb;

/*
 * user_role : rle organisationnel de l'utilistateur, permet de dterminer les responsabilits 
 *                       d'un utilisateur particulier (voir rgles de gestion...)
 */
create table role(
  /* cl */
  id int auto_increment not null,
  /* nom associ au rle */
  name varchar(20) not null,
  /* contraintes */
  primary key(id),
  unique key(name)
) type = innodb;

/*
 * login : identifiant de login et mot de passe gnral d'un utilisateur, un utilisateur donn peut avoir
 *               plusieurs identifiants, les identifiants systmes correspondent  une personne fictive (SYSTEM)
 */
create table login (
  /* cl */
  id int auto_increment not null,
  /* id de login */
  uid varchar(15) not null ,
  /* mot de passe gnral */
  password varchar(50) not null,
  /* rfrence au propritaire du login */
  person int  null ,
  /* les contraintes */
  primary key(id),
  unique key(uid),
  key(person),
  foreign  key (person) references person(id)
) type = innodb ;


/*
 * user_in_role : roles organisationels jous par un utilisateur donn
 */
create table user_in_role (
  /* cl */
  login int not null,
  role int not null,
  /* contraintes */
  primary key(login, role),
  key(login),
  key(role),
  foreign key(login) references login(id),
  foreign key(role) references role(id)
) type = innodb;

/*
 * groups : notion de groupe au sens large (classe, groupe systme, groupe d'applications.....)
 *                 un mme groupe peut tre rattach  un ou plusieurs groupes spcialiss...
 */
create table groups (
  /* cl */
  id int auto_increment not null,
  /* nom court du groupe, unique pour le systme */
  name varchar(20) not null,
  /* nom long du groupe */
  long_name varchar(50),
  /* contraintes */
  unique key(name),
  primary key(id)
) type = innodb;

/*
 * class_group : groupe au sens division scolaire (lves d'une mme classe)
 */
create table class_group(
   /* cl */
  id int auto_increment not null,
  /* niveau d'enseignement */
  level varchar(20),
  /* groupe de rattachement */
  groups int not null,
  /* contraintes */
  primary key(id),
  key(groups),
  foreign key (groups) references groups(id)
) type = innodb;

/*
 * unix_group : groupes unix
 */
create table unix_group(
  /* cl */
  id int auto_increment not null,
  /* identifiant numrique du groupe */
  gid_number int not null,
  /* groupe de rattachement */
  groups int,
  /* contraintes */
  unique key(gid_number),
  key(groups),
  foreign key(groups) references groups(id),
  primary key(id),
) type = innodb;

/*
 * quid_group : groupes squid
 */
create table squid_group (
  /* cl */
  id int auto_increment not null,
  /* groupe de rattachement */
  groups int not null,
  /* type de groupe :
   *   - utilisateurs permanents : P
   *   - utilisateurs temporaires : T
   *   - indiffrent : N
   */
  category varchar(2) not null default 'N',
  /* contraintes */
  primary key(id),
  key(groups),
  foreign key(groups) references groups(id)
) type = innodb;


/*
 * group_history : historique des modifications apports aux membres du groupe
 */
create table groups_history (
  /* cl */
  id int auto_increment not null,
  /* le groupe rfrenc */
  groups int not null,
  /* login de l'utilsateur qui a effectu la modification */
  modifier int not null,
  /* login de l'utilisateur concern par la modification */
  member int not null,
  /* 
    * type de la modification effectue : 
    *   - ajout d'un membre : MA
    *   - retrait d'un membre : MR
    *   - ajout d'un superviseur : SA
    *   - retrait d'un superviseur : SR 
    */
  modification_type varchar(2),
  /* date de la modification */
  modification_date timestamp not null,
  /* contraintes */
  key(groups),
  foreign key(groups) references groups(id),
  key(modifier),
  foreign key(modifier) references login(id),
  key(member),
  foreign key(member) references login(id),
  primary key(id)
) type = innodb;


create table unix_user (
  /* cl */
  id int auto_increment not null,
  /* numro d'utilisateur */
  uid_number int not null,
  /* groupe primaire de l'utilisateur  */
  primary_group int not null,
  /* shell  de login */
  login_shell varchar(40) not null default '/bin/bash',
  /*  rpertoire perso */
  home_directory varchar(100) not null,
  /* commentaire */
  gecos varchar(100) null,
  /* login associ */
  login int not null,
  /* contraintes */
  primary key(id),
  unique key(uid_number),
  key(login),
  foreign key (login) references login(id),
  key(primary_group),
  foreign key(primary_group) references groups(id)
) type = innodb;

/*
 * novell_users : les utilisateurs dfinis sur les serveurs novell
 */

create table novell_user (
  /* cl */
  id int auto_increment not null,
  /* mot de passe */
  password varchar(50) not null,
  /* unit organisationnelle */
  organizational_unit varchar(100),
  /* login associ */
  login int not null,
  /* contraintes */
  primary key(id),
  key(login),
  foreign key(login) references login(id)
) type = innodb;

/*
 * squid_users : paramtres des utilisateurs autoriss de squid
 */
create table squid_user(
  /* cl */
  id int auto_increment not null,
  /* catgorie d'utilisateur du proxy : 
        - permanent : P
        - temporaire : T
        - non autoris : N (possible, mais charte non signe par exemple)
  */
  category varchar(2) not null default 'N',
  /* date de dernire modification de la catgorie */
  category_date timestamp not null,
  /* login du dernier utilisateur  avoir modifi la catgorie */
  category_modifier int not null,
  /* Droit d'accs au proxy 
        - autoris : A
        - non disponible : D
   */
  access varchar(2) not null default 'D',
  /* dernire date de modification du droit d'accs */
  grant_date timestamp not null,
  /* login du dernier utilisateur qui a modifi le droit d'accs */
  granter int not null,
  /* login associ */
  login int not null,
  /* contraintes */
  primary key(id),
  key(category_modifier),
  foreign key(category_modifier) references login(id),
  key(granter),
  foreign key (granter) references login(id),
  key(login),
  foreign key(login) references login(id)
) type = innodb;

/*
 * squid_user_history : suivi des modifications des proprits des utilisateurs squid
 */
create table squid_user_history(
  /* cl */
  id int auto_increment not null,
  /* utilisateur squid concern par la modification */
  user int not null,
  /* date de la modification */
  mod_date timestamp not null,
  /* nature de la modification :
   *   - cration de l'utilisateur squid : C
   *   - categorie permanent : P
   *   - categorie temporaire : T
   *   - categorie non autoris : N
   *   - accs temporaire accord : A
   *   - accs temporaire refus : D
   */
  mod_type varchar(2) not null,
  /* login de l'auteur de la modification */
  by_who int not null,
  /* contraintes */
  primary key(id),
  key(by_who),
  foreign key(by_who) references login(id),
  key(user),
  foreign key(user) references squid_user(id) 
) type = innodb;

/*
 *  mail_alias : alias de courrier lectronique
 */
create table mail_alias(
  /* cl */
  id int auto_increment not null,
  /* le nom d'alias */
  alias varchar(64) not null,
  /* l'utilisateur propritaire de l'alias */
  login int not null,
  /* contraintes */
  primary key(id),
  unique key(alias),
  key(login),
  foreign key(login) references login(id)
) type = innodb;


/*
 *  groups_acl : utilisateurs autoriss  grer les groupes et leur niveau d'autorisation
 */

create table groups_acl(
  /* cl */
  id int auto_increment not null,
  /* l'utilisateur */
  login int not null,
  /* le groupe */
  groups int not null,
  /* les droits */
  permissions varchar(20) not null,
  /* contraintes */
  primary key(id),
  unique key(login, groups),
  key(groups),
  key(login),
  foreign key(login) references login(id),
  foreign key(groups) references groups(id)
) type = innodb;


/*
 * groups_members : utilisateurs membres d'un groupe
 */
create table groups_member (
  /* cl */
  /* l'utilisateur */
  login int not null,
  /* le groupe */
  groups int not null,
  /* contraintes */
  primary key(login, groups),
  key(groups),
  key(login),
  foreign key(login) references login(id),
  foreign key(groups) references groups(id)
) type = innodb;
